@@ -176,7 +176,35 @@ class Client(Singleton):
                 return ret, e
         else:
             return False, '未受支持的Backend'
+
+    async def get_from_cloud_async(self, path, url, force_copy=False, min_size=0):
+        file_path = self.index_cache.get(url)
+        if file_path is not None and os.path.isfile(file_path) and os.path.getsize(file_path) // 1024 >= min_size:
+            print('loading from disk...')
+            if force_copy:
+                if file_path == path:
+                    return True, path
+                else:
+                    os.makedirs(os.path.split(path)[0], exist_ok=True)
+                    
+                    shutil.copy(file_path, path)
+                    
+                    return True, path
+            return True, file_path             
         
+        print('loading from cloud...')
+        backend, bucket, bucket_name = self._get_appropriate_backend(url)
+        
+        if backend is not None:
+            ret, e = await backend.get_async(path, bucket, bucket_name)
+            if ret:
+                self.index_cache.set(url, e)
+                return True, path
+            else:
+                return ret, e
+        else:
+            return False, '未受支持的Backend'
+
     def put_from_cloud(self, url, bucket, bucket_name, timeout=120, file_ttl=-1):
         # save to cache
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
@@ -262,7 +290,7 @@ class Client(Singleton):
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
         if not refresh:
             if '://' in url:
-                ret, e = self.get_from_cloud(path, url, force_copy, min_size)
+                ret, e = await self.get_from_cloud_async(path, url, force_copy, min_size)
                 return ret, e
             
             print('downloading {}...'.format(url))
@@ -273,7 +301,7 @@ class Client(Singleton):
                 resp = json.loads(cached_resp)
                 if resp['ret']:
                     tmp_url = resp['url']
-                    return self.get_from_cloud(path, tmp_url, force_copy, min_size)
+                    return await self.get_from_cloud_async(path, tmp_url, force_copy, min_size)
         else:
             self.redis.delkey(task_id)
         
