@@ -97,6 +97,8 @@ class MQManager(Singleton):
                 except:
                     ret = False
                 t += 1
+            if ret:
+                print('published')    
             return ret
         except Exception as e:
             print(traceback.print_exc())
